PyXMake Developer Guide: PyXMake.Build.Make.NSIS Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | List of all members
PyXMake.Build.Make.NSIS Class Reference

Base class for all NSIS build events. More...

Inheritance diagram for PyXMake.Build.Make.NSIS:

## Public Member Functions
| __init__ (self, *args, **kwargs)
| FTP (self, user, key, upload_file, host='ftp.dlr.de', path="/public/download/nightly")
| parse (cls, **kwargs)
| create (self, **kwargs)
Public Member Functions inherited from PyXMake.Build.Make.Make
| __posix__ (self, **kwargs)
| AddIncludePath (self, includes)
| AddDependencyPath (self, dependencies)
| UseLibraries (self, libs)
| SourcePath (self, path)
| OutputPath (self, path, files="")
| Environment (self, path, script="ifortvars.bat")
| Preprocessing (self, cmdstring='', inend='', outend='', copyfiles=[], replace={'!DEC$ IF':'#IF','!DEC$ ELSE':'#ELSE','!DEC$ ENDIF':'#ENDIF'})
| Build (self, cmdstring, **kwargs)
| Postprocessing (self, cmdstring='')
| run (cls, **kwargs)
Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __new__ (cls, *args, **kwargs)
| recover (cls, *args)
| classify (cls, *args, **kwargs)
| jsonify (self)
| update (self, **kwargs)
| __repr__ (self)
| __str__ (self)
| __getstate__ (self)
| __setstate__ (self, _dict)

## Public Attributes
str | MakeObjectKind = "NSIS"
| String identifier of current instance.
list | libs = []
list | libdirs = []
list | incdirs = []
| path2exe = os.path.join(PyXMakePath,"Build","bin","nsis","App","NSIS")
| Path to NSIS executable.
str | exe = 'makensis.exe'
| Executable of NSIS.
| makecmd = Utility.GetExecutable("makensis", get_path=True)[-1]
| Adding option to deactivate NSIS and instead use a compressed archive directly.
tuple | makecmd = (self.buildid+".nsh",)
| ftp_client = ftplib.FTP(host, user, key)
| Remote workspace.
| buildid
| Adding option to deactivate NSIS and instead use a compressed archive directly.
| outdir = kwargs.get("key","")
| Adding option to deactivate NSIS and instead use a compressed archive directly.
| srcs
| srcdir
| Adding option to deactivate NSIS and instead use a compressed archive directly.
| verbose
| Adding option to deactivate NSIS and instead use a compressed archive directly.
| temps = (MakeFile,)
Public Attributes inherited from PyXMake.Build.Make.Make
| buildid = BuildID
| Base string of build object.
list | srcs = []
| Source file or folders.
list | bare = not BuildID and not self.srcs
| stype = kwargs.get("stype",'Fortran')
| Source file type.
| verbose = verbose
| Level of verbosity of the current build object.
| hasFoss = kwargs.get("foss", Utility.GetExecutable("choco") or Utility.GetPlatform() in ["linux"] or kwargs.get("bash",False))
| Toggle between free open source software and commercial 3rd party libraries.
| scrtdir = os.getcwd()
| Current scratch directory
| srcdir = os.getcwd()
| Default search directory for source files.
| outdir = os.getcwd()
| Default search directory for output.
_, self.intelpath, self.iniCompiler | intelpath = content
| Path to Intel Fortran Compiler (read from Paths.log or empty).
tuple | temps = ()
| Tuple of data to be removed after job completion.
list | incdirs = []
| List of include directories.
list | libdirs = []
| List of library directories.
list | libs = []
| List of actual libraries (by name) used during linking.
list | copyfiles = []
| List of files to be copied to the output directory after finish.
str | iniCompiler = ""
| Default initialization of compiler script.
bool | setarch = True if kwargs.get('arch', None) in ['x86', 'x64'] else False
| Define the architecture for the build directly by using the keyword argument "arch".
| msvsc = kwargs.get("msvsc",'vs2015')
| Default version of Microsoft visual studio used by the Intel Fortran Compiler.
str | architecture = 'x86'
| Processor architecture.
str | postcmd = ""
| Post build command.
| buildname = self.temps + (inputfile, )
str | precmd = self.iniCompiler+" "+cmdstring
| Command executed during pre-build event.
| compargs = cmdstring
| Command line arguments passed in by the user.
str | makecmd = self.iniCompiler+" "+os.path.join(self.path2exe,self.exe)+" "+ cmd + cmdstring
| Command executed during build event.
| mkl_dependency

## Additional Inherited Members
Static Public Member Functions inherited from PyXMake.Build.Make.Make
| __parser__ ()
| Detach ()
| F2CPreprocessing (PreprocessingFile)
| sanitize (string, **kwargs)
| setup (*args, **kwargs)
Static Public Member Functions inherited from PyXMake.Tools.Utility.AbstractBase
| __getbase__ (base, cls)
Protected Attributes inherited from PyXMake.Build.Make.Make
list | _mkl_includes = [x for x in self.incdirs if "mkl" in x]

## Detailed Description

Base class for all NSIS build events.

    Inherited class to build projects using NSIS.

Inherited from Make.

## Constructor & Destructor Documentation

## ◆ __init__()

PyXMake.Build.Make.NSIS.__init__ | ( |  | self,
|  | * | args,
|  | ** | kwargs )

    Initialization of PyInstaller class object.

    @note Creates a portable installer of a source folder using NSIS.

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 2590 of file Make.py.

## Member Function Documentation

## ◆ create()

PyXMake.Build.Make.NSIS.create | ( |  | self,
|  | ** | kwargs )

    Execute make command

Reimplemented from PyXMake.Build.Make.Make.

Definition at line 2701 of file Make.py.

## ◆ FTP()

PyXMake.Build.Make.NSIS.FTP | ( |  | self,
|  |  | user,
|  |  | key,
|  |  | upload_file,
|  |  | host = 'ftp.dlr.de',
|  |  | path = "/public/download/nightly" )

    Define settings to establish a FTP connection.

Definition at line 2620 of file Make.py.

## ◆ parse()

PyXMake.Build.Make.NSIS.parse | ( |  | cls,
|  | ** | kwargs )

    Execute the current class as a CLI command.

Definition at line 2634 of file Make.py.

## Member Data Documentation

## ◆ buildid

PyXMake.Build.Make.NSIS.buildid

Adding option to deactivate NSIS and instead use a compressed archive directly.

Useful on POSIX system w/o NSIS support

Definition at line 2710 of file Make.py.

## ◆ exe

str PyXMake.Build.Make.NSIS.exe = 'makensis.exe'

Executable of NSIS.

Definition at line 2609 of file Make.py.

## ◆ ftp_client

PyXMake.Build.Make.NSIS.ftp_client = ftplib.FTP(host, user, key)

Remote workspace.

This is the upload directory for the given file

Definition at line 2627 of file Make.py.

## ◆ incdirs

list PyXMake.Build.Make.NSIS.incdirs = []

Definition at line 2603 of file Make.py.

## ◆ libdirs

list PyXMake.Build.Make.NSIS.libdirs = []

Definition at line 2602 of file Make.py.

## ◆ libs

list PyXMake.Build.Make.NSIS.libs = []

Definition at line 2601 of file Make.py.

## ◆ makecmd [1/2]

PyXMake.Build.Make.NSIS.makecmd = Utility.GetExecutable("makensis", get_path=True)[-1]

Adding option to deactivate NSIS and instead use a compressed archive directly.

Useful on POSIX system w/o NSIS support

Definition at line 2613 of file Make.py.

## ◆ makecmd [2/2]

tuple PyXMake.Build.Make.NSIS.makecmd = (self.buildid+".nsh",)

Definition at line 2614 of file Make.py.

## ◆ MakeObjectKind

str PyXMake.Build.Make.NSIS.MakeObjectKind = "NSIS"

String identifier of current instance.

Definition at line 2598 of file Make.py.

## ◆ outdir

PyXMake.Build.Make.NSIS.outdir = kwargs.get("key","")

Adding option to deactivate NSIS and instead use a compressed archive directly.

Useful on POSIX system w/o NSIS support

Definition at line 2711 of file Make.py.

## ◆ path2exe

PyXMake.Build.Make.NSIS.path2exe = os.path.join(PyXMakePath,"Build","bin","nsis","App","NSIS")

Path to NSIS executable.

Definition at line 2607 of file Make.py.

## ◆ srcdir

PyXMake.Build.Make.NSIS.srcdir

Adding option to deactivate NSIS and instead use a compressed archive directly.

Useful on POSIX system w/o NSIS support

Definition at line 2722 of file Make.py.

## ◆ srcs

PyXMake.Build.Make.NSIS.srcs

Definition at line 2721 of file Make.py.

## ◆ temps

PyXMake.Build.Make.NSIS.temps = (MakeFile,)

Definition at line 2749 of file Make.py.

## ◆ verbose

PyXMake.Build.Make.NSIS.verbose

Adding option to deactivate NSIS and instead use a compressed archive directly.

Useful on POSIX system w/o NSIS support

Definition at line 2741 of file Make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/Build/Make.py